#### Online Appendix 11.1 ####

# load packages
  library(rgdal)
  library(sp)
  library(PBSmapping)
  library(ks)
  library(rgeos)
  library(foreign)
  library(maptools)
  library(adehabitatHR)
  library(adehabitatLT)
  library(FNN)
  library(maps)
  library(raster)

# load data
  loca=read.csv(file.choose())

# set the right date/hour format
  loca$time = as.POSIXct(strptime(loca$time, format = '%Y-%m-%d %H:%M:%S'))

# kernel density estimator

# try using hlscv 
  kernLSCV<-kernelUD(SpatialPoints(loca[, 1:2]), h= "LSCV")

# even by increasing hlim, the algorithm won't converge
# you can see that with function plotLSCV
  plotLSCV(kernLSCV)

# try using href 
  kernhref<-kernelUD(SpatialPoints(loca[, 1:2]), h= "href")

# estimate and plot the 95% isopleth
  kernhref<-getverticeshr(kernhref, percent=95)
  plot(kernhref)

# calculate the area of the 95% isopleth
  gArea(kernhref)

# find PlugIn parameter value with Hpi 
# choose between 4 different "pilots"
  h1 = Hpi(loca[,1:2], pilot='samse', binned = T)
  h2 = Hpi(loca[,1:2], pilot='unconstr', binned = T)
  h3 = Hpi(loca[,1:2], pilot='dunconstr', binned = T)
  h4 = Hpi(loca[,1:2], pilot='amse', binned = T)

# hpi with samse pilot 
  kernPI1 <- kde(loca[,1:2], H=h1)
  cont = contourLevels(kernPI1, cont = 95)
  line = contourLines(x = kernPI1$eval.points[[1]], y = kernPI1$eval.points[[2]], z = kernPI1$estimate, level = cont)
  sldf = ContourLines2SLDF(line)
  plot(sldf)

# convert contour lines into polygons to calculate area
# ignore warning, no need to define coordinate system for now
  sldf = SpatialLines2PolySet(sldf)
  sldf = PolySet2SpatialPolygons(sldf)
  gArea(sldf)

# hpi with unconstr pilot 
  kernPI2 <- kde(loca[,1:2], H=h2)
  cont = contourLevels(kernPI2, cont = 95)
  line = contourLines(x = kernPI2$eval.points[[1]], y = kernPI2$eval.points[[2]], z = kernPI2$estimate, level = cont)
  sldf = ContourLines2SLDF(line)
  plot(sldf)

# convert contour lines into polygons to calculate area
# ignore warning, no need to define coordinate system for now
  sldf = SpatialLines2PolySet(sldf)
  sldf = PolySet2SpatialPolygons(sldf)
  gArea(sldf)

# first create list of polygons of different isopleths 
  SPDF=list()
  levels=seq(95,50,by=-2.5)
  for (j in 1 : length(levels)){
    cat(j,"\n")
  
  # extract every isopleth (contour line) of level j
    cont = contourLevels(kernPI1, cont = levels[j])
    line = contourLines(x = kernPI1$eval.points[[1]], y = kernPI1$eval.points[[2]], z = kernPI1$estimate, level = cont)
    sldf = ContourLines2SLDF(line)
  
  # set projection (UTM) for polygons
    utm = names(sort(table(as.character(loca$utmzone)))[1])
    utm = gsub('N|S', '', toupper(utm))
    proj4string(sldf) = CRS(paste("+proj=utm +zone=", utm, " +datum=NAD83 +ellps.default=GCS", sep = ''))
 
  # convert contour lines into polygons
    sldf = SpatialLines2PolySet(sldf)
    sldf = PolySet2SpatialPolygons(sldf)
  
  # list of every polygons made with each contour level
    SPDF[[j]]=sldf
    names(SPDF)[j]=levels[j]
  }

# set shading colours for every contour lines 
  cols = colorRampPalette(c("yellow","red"))
  cols = cols(length(SPDF))

# borders of every isopleths
  bord = "NA"

# export results on a single plot by overlapping polygons
  plot(SPDF[[1]],col=cols[1],border=bord, axes = F, main = "KDE_hpi_SAMSE")
  for (i in 2 : length(SPDF)){
    plot(SPDF[[i]],col=cols[i],border=bord, add=T)
  }

# optional: add fixes and scalebar
  points(loca[, 1:2],pch=4,cex=0.75)
  scalebar(d=10000,type="bar",label=c("0","","10km"))

## local Convex Hull methods (LoCoH) 

# transform locations to spatial point objects
  loca_pt<-SpatialPoints(loca[, 1:2])

## LoCoH.k

# define k
  k=sqrt(length(loca_pt))

# investigate relationship between Hr size (area) and k value
# set the range between k= 2*((n^1/2)3) and k= n^1/2
# THIS CALCULUS CAN BE LONG
  LoCoH.k.area(loca_pt,krange=(2*(sqrt(length(loca_pt))/3):sqrt(length(loca_pt))))

# HR with LoCoH using k-value proposed by Getz et al. (2007)
  Hullk<-LoCoH.k(loca_pt,k=k)

# include UD in HR estimate using k-LocoH 
  plot(Hullk, col = colorRampPalette(c("red","yellow"))(length(Hullk)), border = 'NA', axes=F,main="k-LoCoH")

# optional: add fixes and scalebar
  points(loca_pt,pch=4,cex=0.75)
  scalebar(d=10000,type="bar",label=c("0","","10km"))

# associate polygons of different isopleth to colors 
  attributs = Hullk@data
  color = colorRampPalette(c("red","yellow"))(length(Hullk))
  dat = cbind(attributs, color)
  dat
  
# calculate area of largest polygon (last in list, 323)
  gArea(Hullk[323,])
  
## LoCoH.r 
  
# use get.knn to get nearest neighbour of each point
# then define r
  r<-get.knn(as.data.frame(loca_pt))
  r<-(max(r$nn.dist,na.rm=T))/2
  
# investigate relationship between Hr size (area) and r value
# set range between r= half on Max NN distance between points 
# and r=  Max NN distance between points
# THIS CALCULUS CAN BE LONG
  LoCoH.r.area(loca_pt,rrange=(r:2*r), percent=95)
  
# HR with r-LoCoH using r-value proposed by Getz et al. (2007)
  Hullr<-LoCoH.r(loca_pt,r=r)
  
# include UD in HR estimate using r-LocoH
  plot(Hullr, col = colorRampPalette(c("red","yellow"))(length(Hullr)), border = 'NA', axes=F,main="r-LoCoH")
  
# optional: add fixes and scalebar
  points(loca_pt,pch=4,cex=0.75)
  scalebar(d=10000,type="bar",label=c("0","","10km"))
  
# associate polygons of different isopleth to colors 
  attributs = Hullr@data
  color = colorRampPalette(c("red","yellow"))(length(Hullr))
  dat = cbind(attributs, color)
  dat

# calculate area of largest polygon (last in list, 323)
  gArea(Hullr[323,])
  
## LoCoH.a 
  
# define a
  a<-max(spDists(loca_pt),latlong=F)

# investigate relationship between Hr size (area) and a value
# set the range between a=(Max distance between points)/2 
# and a=  Max distance between points
# THIS CALCULUS CAN BE LONG
  LoCoH.a.area(loca_pt,arange=((a/2):a), percent=95) 

# HR with a-LoCoH using a-value suggested by Getz et al. (2007)
  Hulla<-LoCoH.a(loca_pt,a=a)

# include UD in HR estimate using r-LocoH
  plot(Hulla, col = colorRampPalette(c("red", "yellow"))(length(Hulla)), border = 'NA', axes=F,main="a-LoCoH")

# optional: add fixes and scalebar
  scalebar(d=10000,type="bar",label=c("0","","10km"))
  points(loca_pt,pch=4,cex=0.75)

# associate polygons of different isopleth to colors 
  attributs = Hulla@data
  color = colorRampPalette(c("red","yellow"))(length(Hulla))
  dat = cbind(attributs, color)
  dat
  
# calculate area of largest polygon (last in list, 323)
  gArea(Hulla[323,])
  
## Biased Random Bridge

# extract the trajectory from fixes 
  loc.ltraj <- as.ltraj(xy = loca[,1:2], date = loca$time,id=1, typeII = TRUE)

# estimate diffusion parameter D
  vv <- BRB.likD(loc.ltraj, Tmax=4*60*60, Lmin=50) 
  
# estimate UD 
  BRB <- BRB(loc.ltraj, D = vv, Tmax = 4*60*60, Lmin = 50, type = "UD", hmin=500, grid = 500, extent = 3)

# first create list of polygons of different isopleths 
  SPDF=list()
  levels=seq(95,50,by=-5)
  for (j in 1 : length(levels)){
    cat(j,"\n")
    
  # extract every isopleth (contour line) of level j
    cont = contourLevels(kernPI1, cont = levels[j])
    line = contourLines(x = kernPI1$eval.points[[1]],y = kernPI1$eval.points[[2]], z = kernPI1$estimate, level = cont)
    sldf = ContourLines2SLDF(line)
    
  # set projection (UTM) for polygons
    utm = names(sort(table(as.character(loca$utmzone)))[1])
    utm = gsub('N|S', '', toupper(utm))
    proj4string(sldf) = CRS(paste("+proj=utm +zone=", utm, " +datum=NAD83 +ellps.default=GCS", sep = ''))
  
  # extract every isopleth of level j
    verBRB <- getverticeshr(BRB,percent = levels[j])
  
  
# list of every polygon made with each contour level
  SPDF[[j]]=verBRB
  names(SPDF)[j]=levels[j]  
  }

# set shading colors for every contour lines 
  cols = colorRampPalette(c("yellow","red"))
  cols = cols(length(SPDF))
  
# borders of every isopleth
  bord = 'NA'

# export results on a single plot by overlapping polygons
  plot(SPDF[[1]],col=cols[1],border=bord, axes = F, main = "BRB_Tmax=4 hours")
  for (i in 2 : length(SPDF)){
  plot(SPDF[[i]],col=cols[i],border=bord, add=T)
  }
  
# optional: add fixes and scalebar
  points(loca_pt,pch=4,cex=0.75)
  scalebar(d=10000,type="bar",label=c("0","","10km"))

